==> mozilla_1.0.0.orig.tar.gz: mozilla/modules/plugin/tools/tester/windows/guiprefs.h <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: NPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Netscape Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/NPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is 
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or 
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the NPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the NPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#ifndef __GUIPREFS_H__
#define __GUIPREFS_H__

#define SECTION_PREFERENCES         "Preferences"
#define KEY_AUTO_MODE               "AutoMode"
#define KEY_LOG_FILE                "LogFile"
#define KEY_SCRIPT_FILE             "ScriptFile"
#define KEY_TO_FILE                 "LogToFile"
#define KEY_TO_FRAME                "LogToFrame"
#define KEY_FLUSH_NOW               "FlushImmediately"
#define KEY_LOADSTATUS_WINDOW       "LoadStatusWindow"
#define KEY_REMEMBER_LAST_API_CALL  "RememberLastAPICall"
#define KEY_LAST_API_CALL           "LastAPICall"

#define ENTRY_YES             "Yes"
#define ENTRY_NO              "No"

#endif // __GUIPREFS_H__

==> mozilla_1.7.3.orig.tar.gz: mozilla/modules/plugin/tools/tester/windows/guiprefs.h <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: NPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Netscape Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/NPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is 
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or 
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the NPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the NPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#ifndef __GUIPREFS_H__
#define __GUIPREFS_H__

#define SECTION_PREFERENCES         "Preferences"
#define KEY_AUTO_MODE               "AutoMode"
#define KEY_LOG_FILE                "LogFile"
#define KEY_SCRIPT_FILE             "ScriptFile"
#define KEY_TO_FILE                 "LogToFile"
#define KEY_TO_FRAME                "LogToFrame"
#define KEY_FLUSH_NOW               "FlushImmediately"
#define KEY_LOADSTATUS_WINDOW       "LoadStatusWindow"
#define KEY_REMEMBER_LAST_API_CALL  "RememberLastAPICall"
#define KEY_LAST_API_CALL           "LastAPICall"
#define KEY_STAND_ALONE             "StandAloneWindow"
#define KEY_AUTOSTART_SCRIPT        "AutoStartScript"

#define ENTRY_YES             "Yes"
#define ENTRY_NO              "No"

#endif // __GUIPREFS_H__
